@@ -468,38 +468,12 @@ win_associated_files(Files) :-
     (   Files = [File|_]
     ->  absolute_file_name(File, AbsFile),
         set_prolog_flag(associated_file, AbsFile),
-        set_working_directory(File),
-        set_window_title(Files)
+        forall(prolog:set_app_file_config(Files), true)
     ;   true
     ).
 
-%!  set_working_directory(+File)
-%
-%   When opening as a GUI application, e.g.,  by opening a file from
-%   the Finder/Explorer/..., we typically  want   to  change working
-%   directory to the location of  the   primary  file.  We currently
-%   detect that we are a GUI app  by the Prolog flag `console_menu`,
-%   which is set by swipl-win[.exe].
-
-set_working_directory(File) :-
-    current_prolog_flag(console_menu, true),
-    access_file(File, read),
-    !,
-    file_directory_name(File, Dir),
-    working_directory(_, Dir).
-set_working_directory(_).
-
-set_window_title([File|More]) :-
-    current_predicate(system:window_title/2),
-    !,
-    (   More == []
-    ->  Extra = []
-    ;   Extra = ['...']
-    ),
-    atomic_list_concat(['SWI-Prolog --', File | Extra], ' ', Title),
-    system:window_title(_, Title).
-set_window_title(_).
-
+:- multifile
+    prolog:set_app_file_config/1.               % +Files
 
 %!  start_pldoc
 %
@@ -589,6 +563,7 @@ main_thread_init :-
     exists_source(library(epilog)),
     !,
     setup_theme,
+    catch(setup_backtrace, E, print_message(warning, E)),
     use_module(library(epilog)),
     call(epilog([ init(user_thread_init),
                   main(true)
@@ -606,6 +581,7 @@ user_thread_init :-
     argv_prolog_files(Files, ScriptMode),
     load_init_file(ScriptMode),                 % -f file
     catch(setup_colors, E, print_message(warning, E)),
+    '$load_history',
     win_associated_files(Files),                % swipl-win: cd and update title
     '$load_script_file',                        % -s file (may be repeated)
     load_associated_files(Files),
@@ -661,7 +637,7 @@ apply_define(Def) :-
 	->  true
 	;   Value = Value0
 	),
-	create_prolog_flag(Flag, Value, [warn_not_accessed(true)])
+	set_defined(Flag, Value)
     ).
 apply_define(Def) :-
     atom_concat('no-', Flag, Def),
@@ -678,7 +654,7 @@ set_user_boolean_flag(Flag, Value) :-
     ;   set_prolog_flag(Flag, Value)
     ).
 set_user_boolean_flag(Flag, Value) :-
-    create_prolog_flag(Flag, Value, [warn_not_accessed(true)]).
+    set_defined(Flag, Value).
 
 text_flag_value(integer, Text, Int) :-
     atom_number(Text, Int),
@@ -691,6 +667,22 @@ text_flag_value(term, Text, Term) :-
     !.
 text_flag_value(_, Value, Value).
 
+set_defined(Flag, Value) :-
+    define_options(Flag, Options), !,
+    create_prolog_flag(Flag, Value, Options).
+
+%!  define_options(+Flag, -Options)
+%
+%   Define the options with which to create   Flag. This can be used for
+%   known flags to control -for example- their type.
+
+define_options('SDL_VIDEODRIVER', []).
+define_options(_, [warn_not_accessed(true)]).
+
+%!  init_optimise
+%
+%   Load library(apply_macros) if ``-O`` is effective.
+
 init_optimise :-
     current_prolog_flag(optimise, true),
     !,
@@ -935,7 +927,7 @@ setup_macos_app :-
     restore_working_directory,
     !.
 setup_macos_app :-
-    expand_file_name('~/Documents/Prolog', [PrologDir]),
+    expand_file_name('~/Prolog', [PrologDir]),
     (   exists_directory(PrologDir)
     ->  true
     ;   catch(make_directory(PrologDir), MkDirError,
